@@ -29,9 +29,11 @@ class ApiConfig(abc.ABC):
         config_result = requests.get(ARCHIMEDES_API_CONFIG_URL, headers={"Cache-Control": "no-cache"})
         self.config = config_result.json()
         if env not in self.config.keys():
-            raise InvalidEnvironmentException(f"Invalid environment {env}, "
-                                              f"supported values are {self.config.keys}")
-        self.environment = env
+            raise InvalidEnvironmentException(
+                f"Invalid environment {env}, "
+                f"supported values are {', '.join([str(key) for key in self.config.keys()])}"
+            )
+        self.environment = env.lower()
 
     def __getattr__(self, item):
         env_config = self.config[self.environment]
